#[non_exhaustive]pub enum GatewayAccountModeVerificationError {
AccountModeMismatch {
required: GatewayAccountMode,
observed: GatewayAccountMode,
},
Gateway(GatewayError),
}Expand description
Why a resolved gateway could not be authorized for a provider submission.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AccountModeMismatch
The account answered successfully but is not in the trusted deployment mode.
Fields

required: GatewayAccountModeMode required by trusted service or low-level caller configuration.

observed: GatewayAccountModeMode observed from the provider account for this submission authority.
Gateway(GatewayError)
The provider account-mode query failed.