pub enum HostChargeReservationDecision {
Reserved(HostChargeTargetSnapshot),
IdempotentContender(HostChargeTargetSnapshot),
Rejected {
reason: HostChargeTargetRejection,
},
}Variants
Reserved(HostChargeTargetSnapshot)
IdempotentContender(HostChargeTargetSnapshot)
The target is already claimed by this idempotency key.
The current snapshot is mandatory so the ledger can still reject a same-key replay after host-owned economics changed.
Rejected
Fields

reason: HostChargeTargetRejectionTrait Implementations
Sourceimpl Clone for HostChargeReservationDecision
impl Clone for HostChargeReservationDecision
Sourcefn clone(&self) -> HostChargeReservationDecision
fn clone(&self) -> HostChargeReservationDecision
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for HostChargeReservationDecision
impl Eq for HostChargeReservationDecision
impl StructuralPartialEq for HostChargeReservationDecision